@@ -2,7 +2,7 @@
  *
  * Copyright 1998  Jochen Voss.  */
 
-static const  char  rcsid[] = "$Id: vclock.c,v 1.7 2000/03/17 23:01:51 voss Rel $";
+static const  char  rcsid[] = "$Id: vclock.c 5726 2004-06-01 21:22:28Z voss $";
 
 
 #ifdef HAVE_CONFIG_H
@@ -25,7 +25,7 @@ static const  char  rcsid[] = "$Id: vclock.c,v 1.7 2000/03/17 23:01:51 voss Rel
 double
 vclock (void)
 /* Return the elapsed (wall clock) time (measured in seconds) since
- * some base time with greater precision than `clock()' does.  */
+ * some base time with greater precision than `time()' does.  */
 {
   struct timeval  x;
 
